﻿// Copyright (C) 2010 by Crucible-Technologies Ltd.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

//  CTI Comet USB Example Parse Code
//   Ver     Date            Notes               Changes by
//   v1.0    11/04/2011      Original release    Ryan Diver

using System;

namespace COMET_Parse
{
    class COMET_Data
    {
        // Caller ID packet variables
        const byte CALLER_ID = 0x80;
        const byte TIMEDATE = 0x01;
        const byte CALLING_NUMBER = 0x02;
        const byte WHY_NO_NUMBER = 0x04;
        const byte CALLING_NAME = 0x07;
        const byte CALL_TYPE = 0x11;
        const byte WITHHELD = 0x50;
        const byte UNAVAILABLE = 0x4F;
        const byte VOICE = 0x01;
        const byte RINGBACK = 0x02;
        const byte MSG_WAITING = 0x81;

        // Caller ID storage variables
        private string CIDNumber;
        private string CIDName;


        // Variables
        private int i;
        private int bytes_remaining;

        public COMET_Data(int[] data)
        {

            // Check Caller ID packet id
            if (data[0] == CALLER_ID)
            {
                bytes_remaining = data[1];
                i = 2;
                // While still bytes to process
                while (bytes_remaining > 0)
                {
                    int param_length = 0;
                    switch (data[i])
                    {
                        case TIMEDATE:          bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                param_length = data[i]; // Read in length of this parameter
                                                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                // You would parse the time/date here.
                                                // ..............
                                                // Instead we are just discarding
                                                bytes_remaining -= param_length; i += param_length;
                                                break;

                        case CALLING_NUMBER:    bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                param_length = data[i]; // Read in length of this parameter
                                                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                string number = "";
                                                for (;param_length>0;param_length--)
                                                {
                                                       number += (char)data[i];
                                                       bytes_remaining--; i++; // move to next byte and decrease bytes left
                                                }
                                                CIDNumber = number;
                                                break;

                        case CALLING_NAME:      bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                param_length = data[i]; // Read in length of this parameter
                                                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                string name = "";
                                                for (; param_length > 0; param_length--)
                                                {
                                                    name += (char)data[i];
                                                    bytes_remaining--; i++; // move to next byte and decrease bytes left
                                                }
                                                CIDName = name;
                                                break;

                        case WHY_NO_NUMBER:     bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                param_length = data[i]; // Read in length of this parameter
                                                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                // You would parse the why no number here.
                                                // ..............
                                                // Instead we are just discarding
                                                bytes_remaining -= param_length; i += param_length;
                                                break;

                        case CALL_TYPE:         bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                param_length = data[i]; // Read in length of this parameter
                                                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                // You would parse the call type here.
                                                // ..............
                                                // Instead we are just discarding
                                                bytes_remaining -= param_length; i += param_length;
                                                break;  
                        
                        // DISMISS ANY OTHER PARAMETERS
                        default:                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                param_length = data[i]; // Read in length of this parameter
                                                bytes_remaining--; i++; // Move to next byte and decrease bytes left
                                                bytes_remaining -= param_length; i += param_length;
                                                break; 
                        
                    }
                }
            }
            else
                System.Console.WriteLine("ERROR - Not a CID packet!!!");
            
        }

        // Return the CID name
        public string getCIDName()
        {
            return CIDName;
        }

        // Return the CID number
        public string getCIDNumber()
        {
            return CIDNumber;
        }

    }
}
