﻿// Copyright (C) 2010 by Crucible-Technologies Ltd.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

//   CTI Comet USB Example Code
//   Ver     Date            Notes               Changes by
//   v1.0    11/04/2011      Original release    Ryan Diver

// Notes.
//  This code is an example of how to program using the CTI Comet USB.
//  It calls the AutoFind software and uses the first Comet found by default.

using System;
using System.IO.Ports;
using System.Diagnostics; // For process
using COMET_Parse;

namespace COMET_Example
{
    class Program
    {
        private SerialPort serialPort;
        public Program()
        {
            // Find COM port or manually enter it. Uncomment the the option you wish to use
            // Option 1, manually
            //string COM = "COM1";    // Manual
            
            // Option 2, automatically
            string COM = RunProcess("FindCOMET.exe"); // Using the autofind to find the unit's
            string[] COMPorts = COM.Split(';'); // Split the AutoFind string into individual ports
            COM = COMPorts[0]; // Select the first COM port

            // Initialise COM port with all settings.
            serialPort = new SerialPort();
            serialPort.PortName = COM;
            serialPort.BaudRate = 1200;
            serialPort.DataBits = 8;
            serialPort.StopBits = StopBits.One;
            serialPort.Parity = Parity.None;
            serialPort.DataReceived += new SerialDataReceivedEventHandler(this.serialPort_DataReceived);
            serialPort.ReadTimeout = 100; // Required for end of packet Timeout notification
            serialPort.Open();

            // Loop until user presses a key then exit
            System.Console.WriteLine("Press any key to exit");
            Console.ReadKey(); 
        }

        // Variables for the data read
        int[] buffer = new int[255];
        int pointer;

        private void serialPort_DataReceived(object sender, System.IO.Ports.SerialDataReceivedEventArgs e)
        {
            try {
                // Read all the current buffer into the array
                for (int c = 0; c != serialPort.BytesToRead; c++)
                {
                    buffer[pointer] = serialPort.ReadByte();
                    pointer++;
                }

            // If no more bytes then a timeout will occur
            } catch (TimeoutException x) {

                // Parse CID data
                COMET_Data cid = new COMET_Data(buffer);
                
                // Output the data or call something within your program here
                System.Console.Write(cid.getCIDNumber());
                System.Console.Write("\t");
                System.Console.Write(cid.getCIDName());
                System.Console.Write("\n\r");

                // Reset the buffer pointer and buffer
                buffer = new int[255];
                pointer = 0;
            }
        }

        private string RunProcess(String command)
        {
            // Create a new process object
            Process ProcessObj = new Process();

            // StartInfo contains the startup information of
            // the new process
            ProcessObj.StartInfo.FileName = command;
            ProcessObj.StartInfo.Arguments = "";

            // These two optional flags ensure that no DOS window
            // appears
            ProcessObj.StartInfo.UseShellExecute = false;
            ProcessObj.StartInfo.CreateNoWindow = true;

            // This ensures that you get the output from the DOS application
            ProcessObj.StartInfo.RedirectStandardOutput = true;

            // Start the process
            ProcessObj.Start();

            // Wait that the process exits
            ProcessObj.WaitForExit();

            // Now read the output of the DOS application
            return ProcessObj.StandardOutput.ReadToEnd();
        }

         
        static void Main(string[] args)
        {
            new Program();
        }
    }
}
